'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var chalk = _interopDefault(require('chalk'));
var textTable = _interopDefault(require('text-table'));
var logUpdate = _interopDefault(require('log-update'));
var indent = _interopDefault(require('indent-string'));
var wrap = _interopDefault(require('wrap-ansi'));
var getWidth = _interopDefault(require('string-width'));
var stripAnsi = _interopDefault(require('strip-ansi'));

var defaultPatterns = {
  error: 'red',
  success: 'green',
  info: 'cyan',
  warning: 'yellow'
};

var defaultAligns = {
  left: 'l',
  right: 'r'
};

var Lamu = function Lamu(ref) {
  if ( ref === void 0 ) ref = {};
  var align = ref.align; if ( align === void 0 ) align = 'right';
  var lineSpacing = ref.lineSpacing; if ( lineSpacing === void 0 ) lineSpacing = 0;
  var separator = ref.separator; if ( separator === void 0 ) separator = '::';
  var table = ref.table; if ( table === void 0 ) table = true;
  var logger = ref.logger; if ( logger === void 0 ) logger = logUpdate;

  this.messages = [];
  this.align = align;
  this.lineSpacing = lineSpacing;
  this.separator = separator;
  this.table = table;
  this.logger = logger;
};

Lamu.prototype.push = function push (data) {
    var this$1 = this;

  var index = this.messages.length;
  this.updateIndex(index, data);
  for (var i = 0; i < this.lineSpacing; i++) {
    this$1.messages.push(['', '', '']);
  }
  return index
};

Lamu.prototype.log = function log (data) {
  var index = this.push(data);
  this.output();
  return index
};

Lamu.prototype.updateIndex = function updateIndex (index, ref) {
    if ( ref === void 0 ) ref = {};
    var label = ref.label;
    var text = ref.text;
    var color = ref.color;

  var current = this.messages[index];
  label = label || current[0];

  var coloredLabel;
  if (color) {
    label = stripAnsi(label);
    coloredLabel = chalk[color](label);
  } else if (defaultPatterns[label]) {
    label = stripAnsi(label);
    coloredLabel = chalk[defaultPatterns[label]](label);
  } else {
    coloredLabel = chalk.dim(label);
  }

  this.messages[index] = [
    (label || color) ? coloredLabel : current[0],
    chalk.dim(this.separator),
    text || current[2]
  ];
  return this
};

Lamu.prototype.update = function update (index, data) {
  this.updateIndex(index, data);
  this.output();
};

Lamu.prototype.output = function output () {
    var this$1 = this;

  for (var i = 0; i < this.messages.length; i++) {
    this$1.messages[i][2] = this$1.messages[i][2].replace(/^\s*/gm, '');
  }
  var maxLabelWidth = this.messages.reduce(function (current, next) {
    if (getWidth(next[0]) > current) { return getWidth(next[0]) }
    return current
  }, 0);
  var data = this.messages.map(function (message) {
    return [
      message[0],
      message[1],
      this$1.table ? wrapMessage(message, maxLabelWidth) : message[2]
    ]
  });
  if (this.table) {
    this.logger(textTable(data, {
      align: [defaultAligns[this.align], 'l', 'l'],
      stringLength: getWidth
    }));
  } else {
    this.logger(data.map(function (message) {
      return message.join(' ')
    }).join('\n'));
  }
  return this
};

var index = function (options) {
  return new Lamu(options)
};

function wrapMessage(message, maxLabelWidth) {
  var offsetWidth = maxLabelWidth + getWidth(message[1]) + 4;
  var width = process.stdout.columns - offsetWidth;
  return indent(wrap(message[2], width * 0.9), offsetWidth).trim()
}

module.exports = index;
